@@ -30,7 +30,7 @@
 *   tsph tests the forward and reverse spherical coordinate transformation
 *   routines for closure.
 *
-*   $Id: tsph.c,v 2.7 2000/05/10 04:44:05 mcalabre Exp $
+*   $Id: tsph.c,v 2.8 2000/12/04 08:25:58 mcalabre Exp $
 *---------------------------------------------------------------------------*/
 
 #include <math.h>
@@ -46,7 +46,7 @@
 #endif
 
 
-main()
+int main()
 
 {
    int   err, j, lat, lng;
@@ -62,14 +62,14 @@ main()
    eul[0] =  90.0;
    eul[1] =  30.0;
    eul[2] = -90.0;
-   printf("\n%s\n%s%10.4lf%10.4lf%10.4lf\n",
+   printf("\n%s\n%s%10.4f%10.4f%10.4f\n",
       "Celestial longitude and latitude of the native pole, and native",
       "longitude of the celestial pole (degrees):", eul[0], eul[1], eul[2]);
 
    eul[3] = cosd(eul[1]);
    eul[4] = sind(eul[1]);
 
-   printf ("Reporting tolerance:%6.1lg degrees of arc.\n", tol);
+   printf ("Reporting tolerance:%6.1g degrees of arc.\n", tol);
 
    for (lat = 90; lat >= -90; lat--) {
       lat1 = (double)lat;
@@ -79,22 +79,22 @@ main()
          lng1 = (double)lng;
 
          if (err = sphfwd(lng1, lat1, eul, &phi, &theta)) {
-            printf ("lng1 =%20.15lf  lat1 =%20.15lf  Error%3d\n",
+            printf ("lng1 =%20.15f  lat1 =%20.15f  Error%3d\n",
                lng1, lat1, err);
             continue;
          }
 
          if (err = sphrev(phi, theta, eul, &lng2, &lat2)) {
-            printf("lng1 =%20.15lf  lat1 =%20.15lf\n", lng1, lat1);
-            printf(" phi =%20.15lf theta =%20.15lf  Error%3d\n",
+            printf("lng1 =%20.15f  lat1 =%20.15f\n", lng1, lat1);
+            printf(" phi =%20.15f theta =%20.15f  Error%3d\n",
                    phi, theta, err);
             continue;
          }
 
          if (fabs(lat2-lat1) > tol || (fabs(lng2-lng1)-360.0)*coslat > tol) {
-            printf("Unclosed: lng1 =%20.15lf  lat1 =%20.15lf\n", lng1, lat1);
-            printf("           phi =%20.15lf theta =%20.15lf\n", phi, theta);
-            printf("          lng2 =%20.15lf  lat2 =%20.15lf\n", lng2, lat2);
+            printf("Unclosed: lng1 =%20.15f  lat1 =%20.15f\n", lng1, lat1);
+            printf("           phi =%20.15f theta =%20.15f\n", phi, theta);
+            printf("          lng2 =%20.15f  lat2 =%20.15f\n", lng2, lat2);
          }
       }
    }
@@ -109,22 +109,22 @@ main()
          lat1 = (double)j*(90.0 - zeta);
 
          if (err = sphfwd(lng1, lat1, eul, &phi, &theta)) {
-            printf ("lng1 =%20.15lf  lat1 =%20.15lf  Error%3d\n",
+            printf ("lng1 =%20.15f  lat1 =%20.15f  Error%3d\n",
                lng1, lat1, err);
             continue;
          }
 
          if (err = sphrev(phi, theta, eul, &lng2, &lat2)) {
-            printf("lng1 =%20.15lf  lat1 =%20.15lf\n", lng1, lat1);
-            printf(" phi =%20.15lf theta =%20.15lf  Error%3d\n",
+            printf("lng1 =%20.15f  lat1 =%20.15f\n", lng1, lat1);
+            printf(" phi =%20.15f theta =%20.15f  Error%3d\n",
                    phi, theta, err);
             continue;
          }
 
          if (fabs(lat2-lat1) > tol || (fabs(lng2-lng1)-360.0)*coslat > tol) {
-            printf("Unclosed: lng1 =%20.15lf  lat1 =%20.15lf\n", lng1, lat1);
-            printf("           phi =%20.15lf theta =%20.15lf\n", phi, theta);
-            printf("          lng2 =%20.15lf  lat2 =%20.15lf\n", lng2, lat2);
+            printf("Unclosed: lng1 =%20.15f  lat1 =%20.15f\n", lng1, lat1);
+            printf("           phi =%20.15f theta =%20.15f\n", phi, theta);
+            printf("          lng2 =%20.15f  lat2 =%20.15f\n", lng2, lat2);
          }
 
          zeta /= 10.0;
