@@ -84,7 +84,7 @@
 *
 *   Given:
 *      CRVAL    D()      Coordinate reference values corresponding to
-*                        the FITS CRVALn header cards.
+*                        the FITS CRVALn header cards (see note 2).
 *
 *   Given and returned:
 *      CEL      D(10)    Spherical coordinate transformation parameters
@@ -155,7 +155,7 @@
 *
 *   Given:
 *      CRVAL    D()      Coordinate reference values corresponding to
-*                        the FITS CRVALn header cards.
+*                        the FITS CRVALn header cards (see note 2).
 *
 *   Given and returned:
 *      CEL      D(10)    Spherical coordinate transformation parameters
@@ -218,7 +218,7 @@
 *
 *   Given:
 *      CRVAL    D()      Coordinate reference values corresponding to
-*                        the FITS CRVALn header cards.
+*                        the FITS CRVALn header cards (see note 2).
 *
 *   Given and returned:
 *      CEL      D(10)    Spherical coordinate transformation parameters
@@ -271,7 +271,9 @@
 *    3) These routines recognize the NCP projection and convert it to
 *       the equivalent SIN projection.
 *
-*    4) The quadcube projections (CSC, QSC, TSC) may be represented in
+*       They also recognize GLS as a synonym for SFL.
+*
+*    4) The quadcube projections (TSC, CSC, QSC) may be represented in
 *       FITS in either of two ways:
 *
 *          a) The six faces may be laid out in one plane and numbered as
@@ -355,16 +357,16 @@
 *
 *
 *   Author: Mark Calabretta, Australia Telescope National Facility
-*   $Id: wcs.f,v 2.14 2000/05/10 04:49:33 mcalabre Exp $
+*   $Id: wcs.f,v 2.17 2001/02/19 00:42:34 mcalabre Exp $
 *=======================================================================
       SUBROUTINE WCSSET (NAXIS, CTYPE, WCS, IERR)
 *-----------------------------------------------------------------------
       INTEGER   IERR, J, K, NAXIS, WCS(0:3)
-      CHARACTER CTYPE(*)*8, PCODE*3, PCODES*103, REQUIR*8
+      CHARACTER CTYPE(*)*8, PCODE*3, PCODES*120, REQUIR*8
 
-      DATA PCODES(01:40)  /'AZP TAN SIN NCP STG ARC ZPN ZEA AIR CYP '/
-      DATA PCODES(41:80)  /'CAR MER CEA COP COD COE COO BON PCO GLS '/
-      DATA PCODES(81:103) /'PAR AIT MOL CSC QSC TSC'/
+      DATA PCODES(01:40)  /'AZP TAN STG SIN ARC ZPN ZEA AIR CYP CEA '/
+      DATA PCODES(41:80)  /'CAR MER SFL PAR MOL AIT COP COE COD COO '/
+      DATA PCODES(81:120) /'BON PCO TSC CSC QSC             NCP GLS '/
 *-----------------------------------------------------------------------
       PCODE  = ' '
       REQUIR = ' '
@@ -410,6 +412,14 @@
                WCS(2) = J
                K = 1
                REQUIR = CTYPE(J)(1:1) // 'LON-' // PCODE
+            ELSE IF (CTYPE(J)(3:4).EQ.'LN') THEN
+               WCS(1) = J
+               K = 2
+               REQUIR = CTYPE(J)(1:2) // 'LT-' // PCODE
+            ELSE IF (CTYPE(J)(3:4).EQ.'LT') THEN
+               WCS(2) = J
+               K = 1
+               REQUIR = CTYPE(J)(1:2) // 'LN-' // PCODE
             ELSE
 *              Unrecognized celestial type.
                IERR = 1
@@ -433,6 +443,11 @@
          RETURN
       END IF
 
+*     Do simple alias translations.
+      IF (PCODE.EQ.'GLS') THEN
+         PCODE = 'SFL'
+      END IF
+
       IF (PCODE.NE.' ') THEN
          WCS(0) = (INDEX(PCODES,PCODE) - 1)/4 + 1
       ELSE
@@ -451,17 +466,18 @@
       INTEGER   IERR, J, NAXIS, WCS(0:3)
       DOUBLE PRECISION CEL(10), CRVAL(*), IMGCRD(*), LAT, LIN(*), LNG,
      *          OFFSET, PHI, PIXCRD(*), PRJ(0:20), THETA, WORLD(*), X, Y
-      CHARACTER CTYPE(*)*8, PCODE*3, PCODES(26)*3
+      CHARACTER CTYPE(*)*8, PCODE*3, PCODES(30)*3
 
       DOUBLE PRECISION COSD, SIND
 
       DOUBLE PRECISION PI
       PARAMETER (PI = 3.141592653589793238462643D0)
 
-      DATA PCODES /'AZP', 'TAN', 'SIN', 'NCP', 'STG', 'ARC', 'ZPN',
-     *             'ZEA', 'AIR', 'CYP', 'CAR', 'MER', 'CEA', 'COP',
-     *             'COD', 'COE', 'COO', 'BON', 'PCO', 'GLS', 'PAR',
-     *             'AIT', 'MOL', 'CSC', 'QSC', 'TSC'/
+      DATA PCODES /'AZP', 'TAN', 'STG', 'SIN', 'ARC', 'ZPN', 'ZEA',
+     *             'AIR', 'CYP', 'CEA', 'CAR', 'MER', 'SFL', 'PAR',
+     *             'MOL', 'AIT', 'COP', 'COE', 'COD', 'COO', 'BON',
+     *             'PCO', 'TSC', 'CSC', 'QSC', '   ', '   ', '   ',
+     *             'NCP', 'GLS'/
 *-----------------------------------------------------------------------
 *     Number of image axes.
       NAXIS = NINT(LIN(3))
@@ -492,11 +508,16 @@
                RETURN
             END IF
 
-            PCODE = 'SIN'
-            WCS(0)  = 3
+            PCODE   = 'SIN'
+            WCS(0)  = 4
             PRJ(1)  = 0D0
             PRJ(2)  = COSD(CEL(2))/SIND(CEL(2))
-            PRJ(11) = 0D0
+
+            IF (PRJ(11).LT.0D0) THEN
+               PRJ(11) = -1D0
+            ELSE
+               PRJ(11) = 0D0
+            END IF
          END IF
 
          CALL CELFWD (PCODE, LNG, LAT, CEL, PHI, THETA, PRJ, X, Y, IERR)
@@ -554,17 +575,18 @@
       DOUBLE PRECISION CEL(10), CRVAL(*), IMGCRD(*), LIN(*), LAT, LNG,
      *          OFFSET, PHI, PIXCRD(*), PRJ(0:20), THETA, WORLD(*), X,
      *          Y
-      CHARACTER CTYPE(*)*8, PCODE*3, PCODES(26)*3
+      CHARACTER CTYPE(*)*8, PCODE*3, PCODES(30)*3
 
       DOUBLE PRECISION COSD, SIND
 
       DOUBLE PRECISION PI
       PARAMETER (PI = 3.141592653589793238462643D0)
 
-      DATA PCODES /'AZP', 'TAN', 'SIN', 'NCP', 'STG', 'ARC', 'ZPN',
-     *             'ZEA', 'AIR', 'CYP', 'CAR', 'MER', 'CEA', 'COP',
-     *             'COD', 'COE', 'COO', 'BON', 'PCO', 'GLS', 'PAR',
-     *             'AIT', 'MOL', 'CSC', 'QSC', 'TSC'/
+      DATA PCODES /'AZP', 'TAN', 'STG', 'SIN', 'ARC', 'ZPN', 'ZEA',
+     *             'AIR', 'CYP', 'CEA', 'CAR', 'MER', 'SFL', 'PAR',
+     *             'MOL', 'AIT', 'COP', 'COE', 'COD', 'COO', 'BON',
+     *             'PCO', 'TSC', 'CSC', 'QSC', '   ', '   ', '   ',
+     *             'NCP', 'GLS'/
 *-----------------------------------------------------------------------
 *     Number of image axes.
       NAXIS = NINT(LIN(3))
@@ -636,11 +658,16 @@
                RETURN
             END IF
 
-            PCODE = 'SIN'
-            WCS(0)  = 3
+            PCODE   = 'SIN'
+            WCS(0)  = 4
             PRJ(1)  = 0D0
             PRJ(2)  = COSD(CEL(2))/SIND(CEL(2))
-            PRJ(11) = 0D0
+
+            IF (PRJ(11).LT.0D0) THEN
+               PRJ(11) = -1D0
+            ELSE
+               PRJ(11) = 0D0
+            END IF
          END IF
 
          CALL CELREV (PCODE, X, Y, PRJ, PHI, THETA, CEL, LNG, LAT, IERR)
@@ -658,8 +685,8 @@
      *   VITER, WORLD, CRVAL, CEL, PHI, THETA, PRJ, IMGCRD, LIN, PIXCRD,
      *   IERR)
 *-----------------------------------------------------------------------
-      INTEGER   CROSSED, IERR, ISTEP, ITER, J, K, MIXCEL, MIXPIX, NITER,
-     *          NSTEP, RETRY, VITER, WCS(0:3)
+      INTEGER   CROSSED, IERR, ISTEP, ITER, J, K, MIXCEL, MIXPIX, NAXIS,
+     *          NITER, NSTEP, RETRY, VITER, WCS(0:3)
       DOUBLE PRECISION CEL(10), CEL0(10), CRVAL(*), D, D0, D0M, D1, D1M,
      *          DABS, DMIN, DX, IMGCRD(*), LAMBDA, LAT, LAT0, LAT0M,
      *          LAT1, LAT1M, LIN(*), LMIN, LNG, LNG0, LNG0M, LNG1,
@@ -670,6 +697,15 @@
       PARAMETER (NITER = 60)
       PARAMETER (TOL = 1D-10)
 *-----------------------------------------------------------------------
+*     Number of image axes.
+      NAXIS = NINT(LIN(3))
+
+*     Initialize if required.
+      IF (WCS(0).LE.0) THEN
+         CALL WCSSET (NAXIS, CTYPE, WCS, IERR)
+         IF (IERR.NE.0) RETURN
+      END IF
+
 *     Check VSPAN.
       IF (VSPAN(0).LE.VSPAN(1)) THEN
          SPAN(0) = VSPAN(0)
